import Flutter
import UIKit

public class SwiftMediaLibraryPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "@filleduchaos/media_library", binaryMessenger: registrar.messenger())
    let instance = SwiftMediaLibraryPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

   private var library = MediaLibrary()

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    do {
      switch call.method {
      case "executeQuery":
        let query = call.arguments as! [String: Any]
        result(try library.executeQuery(query: query))
      case "loadImage":
        let id = call.arguments as! String
        try library.loadImage(id: id, done: { (data) in
          print("Loaded image data")
          if let bytes = data {
            result(FlutterStandardTypedData(bytes: bytes))
          }
          else {
            result(self.toFlutterError(MediaLibraryError.couldNotLoad(id: id)))
          }
        })
      default:
        result(FlutterMethodNotImplemented)
      }
    }
    catch {
      result(self.toFlutterError(error))
    }
  }
  
  func toFlutterError(_ error: Error) -> FlutterError {
    return FlutterError.init(code: "media_library_error", message: error.localizedDescription, details: nil)
  }
}
