part of media_library;

Type _typeOf<T>() => T;

abstract class _LibraryQuery<T extends Media> {
  int _limit, _offset, _addedDateStart, _addedDateEnd;

  MediaType get type {
    switch (_typeOf<T>()) {
      case ImageMedia:
        return MediaType.image;
      default:
        throw new UnsupportedError('Cannot correctly determine media type');
    }
  }

  _LibraryQuery({ limit = 10, offset = 0 })
    : _limit = limit, _offset = offset;

  void limit(int value) {
    _limit = value;
  }

  void offset(int value) {
    _offset = value;
  }

  void addedBetween(DateTime start, DateTime end) {
    assert(end.compareTo(start) > 0);
    _addedDateStart = start.millisecondsSinceEpoch;
    _addedDateEnd = end.millisecondsSinceEpoch;
  }

  void addedOn(DateTime date) {
    final local = date.toLocal();
    addedBetween(DateTime(local.year, local.month, local.day), DateTime(local.year, local.month, local.day + 1));
  }

  Map<String, dynamic> asMap() => {
    'limit': _limit,
    'offset': _offset,
    'type': type.index,
    'addedDateStart': _addedDateStart,
    'addedDateEnd': _addedDateEnd,
  };

  Future<List<T>> get() async => (await _Channel.call<List>(
    'executeQuery',
    asMap(),
  )).map((result) => _deserialize(Map<String, dynamic>.from(result)) as T).toList();

  _deserialize(Map<String, dynamic> json) {
    switch (type) {
      case MediaType.image:
        return ImageMedia._fromJson(json) as T;
    }
  }
}

class _ImageQuery extends _LibraryQuery<ImageMedia> {
  // _ImageQuery({ int limit, int offset }) : super(limit: limit, offset: offset);
}
