import 'dart:convert';
import 'dart:io' as io;

import 'package:flutter/services.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:media_library/media_library.dart';

const Map<int, String> _assetTypes = {
  0: "image"
};

List<Map> _executeQuery(Map query, List<Map> rows) {
  return rows.where((row) => row['type'] == _assetTypes[query['type']]).
  skip(query['offset']).
  take(query['limit']).
  toList();
}

void prepare() {
  const MethodChannel channel = MethodChannel(kMediaLibraryChannelName);
  List<Map> rows;
  final testDataPath = io.Platform.script.resolve('fixtures/test_data.json');

  setUpAll(() async {
    final contents = await io.File.fromUri(testDataPath).readAsString();
    rows = (jsonDecode(contents) as List).cast<Map>();
  });

  setUp(() {
    channel.setMockMethodCallHandler((MethodCall call) async {
      switch (call.method) {
        case 'executeQuery':
          return _executeQuery(call.arguments, rows);
        default:
          throw MissingPluginException();
      }
    });
  });

  tearDown(() {
    channel.setMockMethodCallHandler(null);
  });
}
