import 'package:flutter_test/flutter_test.dart';
import 'package:media_library/media_library.dart';

import 'harness.dart';

void main() {
  prepare();

  group('Image query builder', () {
    test('returns first ten images by default', () async {
      final results = await MediaLibrary.images().get();
      expect(results.length, 10);
      expect(results.first.id, 'first');
      expect(results.last.id, 'eighteenth');
    });

    test('respects the limit if given', () async {
      final results = await (MediaLibrary.images()..limit(5)).get();
      expect(results.length, 5);
      expect(results.first.id, 'first');
      expect(results.last.id, 'eighth');
    });

    test('respects the offset if given', () async {
      final results = await (MediaLibrary.images()..offset(5)).get();
      expect(results.length, 10);
      expect(results.first.id, 'ninth');
      expect(results.last.id, 'twenty-third');
    });

    test('respects both limit and offset', () async {
      final results = await (MediaLibrary.images()..limit(5)..offset(5)).get();
      expect(results.length, 5);
      expect(results.first.id, 'ninth');
      expect(results.last.id, 'eighteenth');
    });
  });
}
